Coverage report

# Coverage report: 77%

Hot-keys on this page

n s m x b p c change column sorting

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 8294 | 1712 | 0 | 3758 | 460 | 77%
gramex\__init__.py | 142 | 27 | 0 | 68 | 7 | 79%
gramex\apps\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
gramex\apps\languagetool\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
gramex\apps\logviewer\__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
gramex\apps\logviewer\logviewer.py | 207 | 38 | 0 | 92 | 14 | 77%
gramex\apps\nlg\__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
gramex\apps\nlg\grammar.py | 85 | 16 | 0 | 52 | 6 | 80%
gramex\apps\nlg\nlgapp.py | 148 | 120 | 0 | 38 | 1 | 16%
gramex\apps\nlg\nlgsearch.py | 148 | 6 | 0 | 110 | 7 | 94%
gramex\apps\nlg\nlgutils.py | 105 | 25 | 0 | 63 | 4 | 72%
gramex\apps\ui\__init__.py | 49 | 11 | 0 | 16 | 3 | 75%
gramex\cache.py | 586 | 103 | 0 | 272 | 24 | 80%
gramex\config.py | 403 | 44 | 0 | 214 | 15 | 89%
gramex\data.py | 628 | 42 | 0 | 390 | 29 | 92%
gramex\debug.py | 118 | 84 | 0 | 32 | 2 | 24%
gramex\handlers\__init__.py | 25 | 2 | 0 | 2 | 1 | 89%
gramex\handlers\authhandler.py | 225 | 69 | 0 | 75 | 10 | 66%
gramex\handlers\basehandler.py | 515 | 87 | 0 | 272 | 29 | 80%
gramex\handlers\capturehandler.py | 184 | 82 | 0 | 56 | 9 | 48%
gramex\handlers\drivehandler.py | 137 | 9 | 0 | 68 | 7 | 90%
gramex\handlers\filehandler.py | 173 | 7 | 0 | 96 | 5 | 96%
gramex\handlers\filterhandler.py | 4 | 0 | 0 | 0 | 0 | 100%
gramex\handlers\formhandler.py | 172 | 12 | 0 | 104 | 12 | 91%
gramex\handlers\functionhandler.py | 36 | 2 | 0 | 18 | 2 | 93%
gramex\handlers\jsonhandler.py | 106 | 6 | 0 | 34 | 3 | 94%
gramex\handlers\modelhandler.py | 96 | 21 | 0 | 35 | 8 | 78%
gramex\handlers\pptxhandler.py | 13 | 0 | 0 | 2 | 0 | 100%
gramex\handlers\processhandler.py | 61 | 3 | 0 | 22 | 3 | 93%
gramex\handlers\proxyhandler.py | 61 | 4 | 0 | 34 | 7 | 86%
gramex\handlers\socialhandler.py | 138 | 57 | 0 | 55 | 8 | 54%
gramex\handlers\uploadhandler.py | 155 | 20 | 0 | 76 | 9 | 86%
gramex\handlers\websockethandler.py | 23 | 10 | 0 | 14 | 0 | 51%
gramex\http.py | 52 | 0 | 0 | 0 | 0 | 100%
gramex\install.py | 389 | 126 | 0 | 186 | 35 | 63%
gramex\license.py | 33 | 5 | 0 | 6 | 2 | 82%
gramex\ml.py | 258 | 102 | 0 | 96 | 18 | 59%
gramex\pptgen\__init__.py | 162 | 17 | 0 | 84 | 9 | 89%
gramex\pptgen\color.py | 159 | 64 | 0 | 70 | 8 | 53%
gramex\pptgen\commands.py | 706 | 50 | 0 | 307 | 56 | 89%
gramex\pptgen\fontwidth.py | 23 | 0 | 0 | 6 | 2 | 93%
gramex\pptgen\utils.py | 368 | 48 | 0 | 146 | 29 | 82%
gramex\services\__init__.py | 535 | 135 | 0 | 242 | 45 | 73%
gramex\services\emailer.py | 113 | 5 | 0 | 42 | 5 | 94%
gramex\services\scheduler.py | 63 | 1 | 0 | 27 | 2 | 97%
gramex\services\sms.py | 38 | 19 | 0 | 2 | 0 | 48%
gramex\services\ttlcache.py | 161 | 37 | 0 | 23 | 7 | 74%
gramex\services\urlcache.py | 40 | 6 | 0 | 8 | 1 | 81%
gramex\services\watcher.py | 75 | 6 | 0 | 33 | 2 | 93%
gramex\transforms\__init__.py | 7 | 0 | 0 | 0 | 0 | 100%
gramex\transforms\auth.py | 19 | 2 | 0 | 14 | 4 | 82%
gramex\transforms\badgerfish.py | 17 | 8 | 0 | 8 | 0 | 36%
gramex\transforms\rmarkdown.py | 9 | 6 | 0 | 0 | 0 | 33%
gramex\transforms\template.py | 26 | 0 | 0 | 6 | 2 | 94%
gramex\transforms\transforms.py | 154 | 51 | 0 | 92 | 8 | 66%
gramex\transforms\twitterstream.py | 143 | 117 | 0 | 50 | 0 | 13%

No items found using the specified filter.